@@ -6,9 +6,7 @@ infodir=${prefix}/share/info
 man1dir=${prefix}/share/man/man1
 
 ${sbindir}/update-alternatives \
-	--install ${bindir}/automake automake ${bindir}/automake-1.11 70 \
-	--slave   ${bindir}/aclocal  aclocal  ${bindir}/aclocal-1.11     \
-	--slave   ${infodir}/automake.info.gz automake-info ${infodir}/automake1.11.info.gz \
+	--install ${infodir}/automake.info.gz automake-doc ${infodir}/automake1.11.info.gz 45 \
 	--slave   ${man1dir}/automake.1.gz automake-man ${man1dir}/automake-1.11.1.gz \
 	--slave   ${man1dir}/aclocal.1.gz aclocal-man ${man1dir}/aclocal-1.11.1.gz
 
